@@ -158,7 +158,10 @@ class Authenticator(models.Model):
             return metadata
         # Take the device certificate and try to validate against all certs in MDS
         device_cert = crypto.load_certificate(crypto.FILETYPE_ASN1, self.attestation.att_statement['x5c'][0])
-        root_certs = json.loads(metadata.detailed_metadata_entry)['attestationRootCertificates']
+        try:
+            root_certs = json.loads(metadata.detailed_metadata_entry)['attestationRootCertificates']
+        except KeyError:
+            root_certs = json.loads(metadata.metadata_entry)['attestationRootCertificates']
         store = self._prepare_store(root_certs)
         store_ctx = crypto.X509StoreContext(store, device_cert)
         try:
@@ -172,7 +175,7 @@ class Authenticator(models.Model):
 class AuthenticatorMetadata(models.Model):
     """Stores information from metadata service."""
 
-    url = models.URLField(unique=True)
+    url = models.URLField(unique=True, null=True, blank=True)
     identifier = models.TextField(unique=True)
     metadata_entry = models.TextField()
     detailed_metadata_entry = models.TextField()
